TrackedFileState class

Constructors

TrackedFileState({required String path, required String content, required DateTime lastModified, required int size})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
lastModified DateTime
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited