McpResourceAdapter class abstract

Constructors

McpResourceAdapter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

listResources({String? server}) Future<List<McpResourceDescriptor>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readResource({required String server, required String uri}) Future<McpResourceContent>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited