VerifyAgent class
Reviews the execution output and validates the result.
- Inheritance
- Mixed-in types
Constructors
- VerifyAgent({required ModelRef model, required GenkitPlugin plugin, required void onMessage(ToolStatus), required ToolRuntime runtime, required String? systemPrompt, required int maxTurns})
- Creates a verification-focused agent.
Properties
- ai ↔ Genkit
-
The configured Genkit instance used to fulfill model requests.
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxTurns → int
-
The maximum number of turns to allow in a conversation.
finalinherited
- model → ModelRef
-
The model name used for requests.
finalinherited
- onMessage → void Function(ToolStatus)
-
The callback function to handle tool messages.
finalinherited
- plugin → GenkitPlugin
-
The plugin used to fulfill model requests.
finalinherited
- runtime → ToolRuntime
-
Shared runtime for stateful tools.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stageInstructions → String
-
Instructions prepended to the user-provided system prompt.
no setteroverride
- systemPrompt → String?
-
The system prompt to use for the agent.
finalinherited
-
tools
↔ List<
Tool> -
The tool definitions exposed to the model during generation.
latefinalinherited
Methods
-
buildTools(
) → List< Tool> -
Builds the list of tools exposed to this agent.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
String prompt, {List< Message> ? messages}) → Future<GenerateResponseHelper> -
Sends
promptto the model and returns the generated text response.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited