SessionTask class
Constructors
Properties
- activeForm ↔ String?
-
getter/setter pair
-
blockedBy
→ List<
String> -
final
-
blocks
→ List<
String> -
final
- description ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
metadata
→ Map<
String, dynamic> -
final
- owner ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ SessionTaskStatus
-
getter/setter pair
- subject ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited